# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import mlp_api_pb2 as mlp__api__pb2


class CatalogStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateProject = channel.unary_unary(
        '/Catalog/CreateProject',
        request_serializer=mlp__api__pb2.CreateProjectRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.ProjectInfoResponse.FromString,
        )
    self.GetProject = channel.unary_unary(
        '/Catalog/GetProject',
        request_serializer=mlp__api__pb2.GetProjectRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.ProjectInfoResponse.FromString,
        )
    self.ListProjects = channel.unary_unary(
        '/Catalog/ListProjects',
        request_serializer=mlp__api__pb2.ListProjectsRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.ListProjectsResponse.FromString,
        )
    self.CreateDataset = channel.unary_unary(
        '/Catalog/CreateDataset',
        request_serializer=mlp__api__pb2.CreateDatasetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.DatasetInfoResponse.FromString,
        )
    self.GetDataset = channel.unary_unary(
        '/Catalog/GetDataset',
        request_serializer=mlp__api__pb2.GetDatasetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.DatasetInfoResponse.FromString,
        )
    self.ListDatasets = channel.unary_unary(
        '/Catalog/ListDatasets',
        request_serializer=mlp__api__pb2.ListDatasetsRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.ListDatasetsResponse.FromString,
        )
    self.UpdateDataset = channel.unary_unary(
        '/Catalog/UpdateDataset',
        request_serializer=mlp__api__pb2.UpdateDatasetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.EmptyResponse.FromString,
        )
    self.AddDatasetActivity = channel.unary_unary(
        '/Catalog/AddDatasetActivity',
        request_serializer=mlp__api__pb2.AddDatasetActivityRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.AddDatasetActivityResponse.FromString,
        )
    self.Stat = channel.unary_unary(
        '/Catalog/Stat',
        request_serializer=mlp__api__pb2.StatRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.StatResponse.FromString,
        )
    self.Reset = channel.unary_unary(
        '/Catalog/Reset',
        request_serializer=mlp__api__pb2.ResetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.EmptyResponse.FromString,
        )


class CatalogServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateProject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetProject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListProjects(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateDataset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDataset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDatasets(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateDataset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddDatasetActivity(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stat(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Reset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CatalogServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateProject': grpc.unary_unary_rpc_method_handler(
          servicer.CreateProject,
          request_deserializer=mlp__api__pb2.CreateProjectRequest.FromString,
          response_serializer=mlp__api__pb2.ProjectInfoResponse.SerializeToString,
      ),
      'GetProject': grpc.unary_unary_rpc_method_handler(
          servicer.GetProject,
          request_deserializer=mlp__api__pb2.GetProjectRequest.FromString,
          response_serializer=mlp__api__pb2.ProjectInfoResponse.SerializeToString,
      ),
      'ListProjects': grpc.unary_unary_rpc_method_handler(
          servicer.ListProjects,
          request_deserializer=mlp__api__pb2.ListProjectsRequest.FromString,
          response_serializer=mlp__api__pb2.ListProjectsResponse.SerializeToString,
      ),
      'CreateDataset': grpc.unary_unary_rpc_method_handler(
          servicer.CreateDataset,
          request_deserializer=mlp__api__pb2.CreateDatasetRequest.FromString,
          response_serializer=mlp__api__pb2.DatasetInfoResponse.SerializeToString,
      ),
      'GetDataset': grpc.unary_unary_rpc_method_handler(
          servicer.GetDataset,
          request_deserializer=mlp__api__pb2.GetDatasetRequest.FromString,
          response_serializer=mlp__api__pb2.DatasetInfoResponse.SerializeToString,
      ),
      'ListDatasets': grpc.unary_unary_rpc_method_handler(
          servicer.ListDatasets,
          request_deserializer=mlp__api__pb2.ListDatasetsRequest.FromString,
          response_serializer=mlp__api__pb2.ListDatasetsResponse.SerializeToString,
      ),
      'UpdateDataset': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateDataset,
          request_deserializer=mlp__api__pb2.UpdateDatasetRequest.FromString,
          response_serializer=mlp__api__pb2.EmptyResponse.SerializeToString,
      ),
      'AddDatasetActivity': grpc.unary_unary_rpc_method_handler(
          servicer.AddDatasetActivity,
          request_deserializer=mlp__api__pb2.AddDatasetActivityRequest.FromString,
          response_serializer=mlp__api__pb2.AddDatasetActivityResponse.SerializeToString,
      ),
      'Stat': grpc.unary_unary_rpc_method_handler(
          servicer.Stat,
          request_deserializer=mlp__api__pb2.StatRequest.FromString,
          response_serializer=mlp__api__pb2.StatResponse.SerializeToString,
      ),
      'Reset': grpc.unary_unary_rpc_method_handler(
          servicer.Reset,
          request_deserializer=mlp__api__pb2.ResetRequest.FromString,
          response_serializer=mlp__api__pb2.EmptyResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'Catalog', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from dataclasses import dataclass
from typing import Callable, Optional

from . import mlp_api_pb2 as api
from . import mlp_api_pb2_grpc as rpc
import grpc
from . import errors
import os
import google.protobuf.message as pb



class EntityId:
    def __init__(self, uid: bytes):
        self.uid= uid

class JobRunId (EntityId):
    pass


class DatasetVersionId(EntityId):
    pass

class SystemId(EntityId):
    pass



class Context:

    def __init__(self, catalog: rpc.CatalogStub):
        self.catalog = catalog

    def create_project(self, req: api.CreateProjectRequest) -> api.ProjectInfoResponse:
        resp: api.ProjectInfoResponse = self._rpc(lambda: self.catalog.CreateProject(req))
        return resp

    def get_project(self, req: api.GetProjectRequest) -> api.ProjectInfoResponse:
        resp: api.ProjectInfoResponse = self._rpc(lambda: self.catalog.GetProject(req))
        return resp

    def list_projects(self, req: api.ListProjectsRequest) -> api.ListProjectsResponse:
        resp: api.ListProjectsResponse = self._rpc(lambda : self.catalog.ListProjects(req))
        return resp


    def create_dataset(self, req: api.CreateDatasetRequest) -> api.DatasetInfoResponse:
        s: api.DatasetInfoResponse = self._rpc(lambda: self.catalog.CreateDataset(req))
        return s

    def get_dataset(self, req: api.GetDatasetRequest) -> api.DatasetInfoResponse:
        s: api.DatasetInfoResponse = self._rpc(lambda: self.catalog.GetDataset(req))
        return s

    def list_datasets(self, req:api.ListDatasetsRequest) -> api.ListDatasetsResponse:
        s:api.ListDatasetsResponse = self._rpc(lambda : self.catalog.ListDatasets(req))
        return s

    def update_dataset(self, req: api.UpdateDatasetRequest) -> api.UpdateDatasetRequest:
        s:api.UpdateDatasetRequest = self._rpc(lambda: self.catalog.UpdateDataset(req))
        return s

    def reset(self):
        self._rpc(lambda : self.catalog.Reset(api.ResetRequest()))

    def stat(self):
        s:api.StatResponse = self._rpc(lambda : self.catalog.Stat(api.StatRequest()))
        return s

    def add_dataset_activity(self, req: api.AddDatasetActivityRequest):
        s:api.AddDatasetActivityResponse = self._rpc(lambda : self.catalog.AddDatasetActivity(req))
        return s

    def _rpc(self, callable: Callable[[], pb.Message]):
        try:

            resp = callable()

            if not hasattr(resp,"error"):

                raise ValueError(print(f'{resp.__class__} has no error attribute'))

            if resp.error.code != 0:
                raise errors.from_error(resp.error)

            return resp
        except grpc.RpcError as e:
            raise errors.from_exception(e)



from typing import List, Sequence

import grpc

from . import mlp_api_pb2 as api

def from_exception(e: grpc.RpcError):
    code, msg = e.code().value

    ctor = MAP.get(code, ClientError)
    return ctor(code, str(e))




class ClientError(Exception):
    """Base class for all exceptions raised by this client"""

    status_code = None


    def __init__(self, status_code:api.StatusCode, message:str, detail_code:str=None,
                 detail_args:List[str]=(), details:List[str]=()):
        super(ClientError, self).__init__(message)
        self.message = message
        self.details = details
        self.status_code = status_code
        self.detail_code=detail_code
        self.detail_args=detail_args


    def __str__(self):
        msg =  f'{self.status_code} {self.message}'
        if self.details:
            msg += f" {self.details}"
        if self.detail_code:
            msg += f"{self.detail_code}({self.detail_args})"
        return msg




class InvalidArgument(ClientError):
    pass
class AlreadyExists(ClientError):
    pass
class BadName(InvalidArgument):
    pass

class NotFound(InvalidArgument):
    pass

class Unavailable(ClientError):
    pass

MAP= {
    api.StatusCode.INVALID_ARGUMENT: InvalidArgument,
    api.StatusCode.ALREADY_EXISTS:AlreadyExists,
    api.StatusCode.BAD_NAME:BadName,
    api.StatusCode.NOT_FOUND:NotFound,
    api.StatusCode.UNAVAILABLE:Unavailable,
}

MAP = {int(k): v for k,v in MAP.items()}

def from_error(e: api.ApiError) -> ClientError:
    ctor = MAP.get(e.code, ClientError)
    return ctor(
        e.code,
        e.message,
        e.detail_code,
        e.detail_args,
        e.details
        )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='vo.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x08vo.proto\"\x97\x01\n\x14\x44\x61tasetMetadataDelta\x12\x17\n\x06sample\x18\x01 \x01(\x0b\x32\x07.Sample\x12\x12\n\nsample_set\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x17\n\x0f\x64\x65scription_set\x18\x06 \x01(\x08\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\x13\n\x0bsummary_set\x18\x08 \x01(\x08\"g\n\x06Sample\x12\x1e\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x0e.Sample.FORMAT\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\"/\n\x06\x46ORMAT\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x07\n\x03TSV\x10\x02\x12\x08\n\x04JSON\x10\x03*c\n\x0e\x41\x43TIVITY_LEVEL\x12\x14\n\x10\x41\x43TIVITY_VERBOSE\x10\x00\x12\x11\n\rACTIVITY_INFO\x10\x01\x12\x12\n\x0e\x41\x43TIVITY_ERROR\x10\x02\x12\x14\n\x10\x41\x43TIVITY_SUCCESS\x10\x03\x62\x06proto3')
)

_ACTIVITY_LEVEL = _descriptor.EnumDescriptor(
  name='ACTIVITY_LEVEL',
  full_name='ACTIVITY_LEVEL',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_VERBOSE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_INFO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_SUCCESS', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=271,
  serialized_end=370,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITY_LEVEL)

ACTIVITY_LEVEL = enum_type_wrapper.EnumTypeWrapper(_ACTIVITY_LEVEL)
ACTIVITY_VERBOSE = 0
ACTIVITY_INFO = 1
ACTIVITY_ERROR = 2
ACTIVITY_SUCCESS = 3


_SAMPLE_FORMAT = _descriptor.EnumDescriptor(
  name='FORMAT',
  full_name='Sample.FORMAT',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSV', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=222,
  serialized_end=269,
)
_sym_db.RegisterEnumDescriptor(_SAMPLE_FORMAT)


_DATASETMETADATADELTA = _descriptor.Descriptor(
  name='DatasetMetadataDelta',
  full_name='DatasetMetadataDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample', full_name='DatasetMetadataDelta.sample', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_set', full_name='DatasetMetadataDelta.sample_set', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='DatasetMetadataDelta.description', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_set', full_name='DatasetMetadataDelta.description_set', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='DatasetMetadataDelta.summary', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_set', full_name='DatasetMetadataDelta.summary_set', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=164,
)


_SAMPLE = _descriptor.Descriptor(
  name='Sample',
  full_name='Sample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='Sample.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='Sample.body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SAMPLE_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=269,
)

_DATASETMETADATADELTA.fields_by_name['sample'].message_type = _SAMPLE
_SAMPLE.fields_by_name['format'].enum_type = _SAMPLE_FORMAT
_SAMPLE_FORMAT.containing_type = _SAMPLE
DESCRIPTOR.message_types_by_name['DatasetMetadataDelta'] = _DATASETMETADATADELTA
DESCRIPTOR.message_types_by_name['Sample'] = _SAMPLE
DESCRIPTOR.enum_types_by_name['ACTIVITY_LEVEL'] = _ACTIVITY_LEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatasetMetadataDelta = _reflection.GeneratedProtocolMessageType('DatasetMetadataDelta', (_message.Message,), {
  'DESCRIPTOR' : _DATASETMETADATADELTA,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:DatasetMetadataDelta)
  })
_sym_db.RegisterMessage(DatasetMetadataDelta)

Sample = _reflection.GeneratedProtocolMessageType('Sample', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLE,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:Sample)
  })
_sym_db.RegisterMessage(Sample)


# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import Optional, Callable, List, Union

from google.protobuf.message import Message

from . import mlp_api_pb2 as api
from . import mlp_api_pb2_grpc as rpc
from . import vo_pb2 as vo
from .cl_project import Project
from .cl_dataset import Dataset
from .cl_bases import Context

from . import errors
import grpc
import google.protobuf.message as pb


class Server():
    def __init__(self, context: Context):
        self.context = context

    def stats(self):

        request = api.StatRequest()
        return self.context.stat()

    def reset_db(self):
        self.context.reset()

class Client():

    def __init__(self, context: Context):
        self.context = context
        self.server = Server(context)





    def get_project(self, project_id) -> Project:

        r = api.GetProjectRequest(project_id=project_id)
        resp = self.context.get_project(r)
        return Project(self.context, project_id=project_id)


    def __getitem__(self, key:str):
        return self.get_project(key)


    def add_project(self, project_id: str) -> Project:


        request = api.CreateProjectRequest(
            project_id=project_id,)

        resp = self.context.create_project(request)
        return Project(self.context, project_id=project_id)





def connect(url):
    channel = grpc.insecure_channel(url)
    catalog = rpc.CatalogStub(channel)

    ctx = Context(catalog)

    return Client(ctx)



from typing import Optional, List, Any

from .cl_bases import *
from . import vo_pb2 as vo
import time


class Dataset:
    def __init__(self, ctx: Context, project_id:str, dataset_id:str):
        self.project_id  = project_id
        self.dataset_id = dataset_id
        self.ctx = ctx


    def add_error(self, multiline_text:str, timestamp_sec:int = 0):
        return self.add_activity(multiline_text=multiline_text, timestamp_sec=timestamp_sec, level="error")

    def add_info(self, multiline_text:str, timestamp_sec:int = 0):
        return self.add_activity(multiline_text=multiline_text, timestamp_sec=timestamp_sec, level="info")
    def add_success(self, multiline_text:str, timestamp_sec:int = 0):
        return self.add_activity(multiline_text=multiline_text, timestamp_sec=timestamp_sec, level="success")


    def add_activity(self, multiline_text:str, timestamp_sec:int = 0, level:Optional[str]=None):


        map = {
            'info': vo.ACTIVITY_INFO,
            'error': vo.ACTIVITY_ERROR,
            'success':vo.ACTIVITY_SUCCESS,
            'verbose':vo.ACTIVITY_VERBOSE,
        }



        req=api.AddDatasetActivityRequest(
            project_id=self.project_id,
            dataset_id=self.dataset_id,
            multiline_text=multiline_text,
            level=map.get(level, vo.ACTIVITY_INFO),
            timestamp=timestamp_sec,
        )

        self.ctx.add_dataset_activity(req)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mlp_api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import vo_pb2 as vo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mlp_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rmlp_api.proto\x1a\x08vo.proto\"*\n\x14\x43reateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\'\n\x11GetProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"!\n\x0bProjectInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\"C\n\x13ProjectInfoResponse\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\";\n\x11GetDatasetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\"c\n\x14\x43reateDatasetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12#\n\x04meta\x18\x03 \x01(\x0b\x32\x15.DatasetMetadataDelta\"c\n\x14UpdateDatasetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12#\n\x04meta\x18\x03 \x01(\x0b\x32\x15.DatasetMetadataDelta\"\x15\n\x13ListProjectsRequest\"P\n\x14ListProjectsResponse\x12\x1e\n\x08projects\x18\x01 \x03(\x0b\x32\x0c.ProjectInfo\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\")\n\x13ListDatasetsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"P\n\x14ListDatasetsResponse\x12\x1e\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x0c.DatasetInfo\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\x8e\x01\n\x0b\x44\x61tasetInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x18\n\x10update_timestamp\x18\x03 \x01(\x03\x12\x17\n\x06sample\x18\x04 \x01(\x0b\x32\x07.Sample\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\"\xb0\x01\n\x13\x44\x61tasetInfoResponse\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x18\n\x10update_timestamp\x18\x03 \x01(\x03\x12\x17\n\x06sample\x18\x04 \x01(\x0b\x32\x07.Sample\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\x8e\x01\n\x19\x41\x64\x64\x44\x61tasetActivityRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x16\n\x0emultiline_text\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x1e\n\x05level\x18\x05 \x01(\x0e\x32\x0f.ACTIVITY_LEVEL\"6\n\x1a\x41\x64\x64\x44\x61tasetActivityResponse\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\r\n\x0bStatRequest\"N\n\x0cStatResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0b\x65vent_count\x18\x02 \x01(\x04\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\x0e\n\x0cResetRequest\"q\n\x08\x41piError\x12\x19\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x0b.StatusCode\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65tail_code\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65tail_args\x18\x04 \x03(\t\x12\x0f\n\x07\x64\x65tails\x18\x06 \x01(\t\")\n\rEmptyResponse\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError*\xf1\x02\n\nStatusCode\x12\x06\n\x02OK\x10\x00\x12\r\n\tCANCELLED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x0c\n\x08\x42\x41\x44_NAME\x10\x64\x12\x0e\n\nNAME_TAKEN\x10\x65\x12\x14\n\x10VERSION_MISMATCH\x10\x66\x32\xd7\x04\n\x07\x43\x61talog\x12>\n\rCreateProject\x12\x15.CreateProjectRequest\x1a\x14.ProjectInfoResponse\"\x00\x12\x38\n\nGetProject\x12\x12.GetProjectRequest\x1a\x14.ProjectInfoResponse\"\x00\x12=\n\x0cListProjects\x12\x14.ListProjectsRequest\x1a\x15.ListProjectsResponse\"\x00\x12>\n\rCreateDataset\x12\x15.CreateDatasetRequest\x1a\x14.DatasetInfoResponse\"\x00\x12\x38\n\nGetDataset\x12\x12.GetDatasetRequest\x1a\x14.DatasetInfoResponse\"\x00\x12=\n\x0cListDatasets\x12\x14.ListDatasetsRequest\x1a\x15.ListDatasetsResponse\"\x00\x12\x38\n\rUpdateDataset\x12\x15.UpdateDatasetRequest\x1a\x0e.EmptyResponse\"\x00\x12O\n\x12\x41\x64\x64\x44\x61tasetActivity\x12\x1a.AddDatasetActivityRequest\x1a\x1b.AddDatasetActivityResponse\"\x00\x12%\n\x04Stat\x12\x0c.StatRequest\x1a\r.StatResponse\"\x00\x12(\n\x05Reset\x12\r.ResetRequest\x1a\x0e.EmptyResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[vo__pb2.DESCRIPTOR,])

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHENTICATED', index=8, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_EXHAUSTED', index=9, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_PRECONDITION', index=10, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=11, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_RANGE', index=12, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIMPLEMENTED', index=13, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=14, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=15, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_LOSS', index=16, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_NAME', index=17, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_TAKEN', index=18, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION_MISMATCH', index=19, number=102,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1504,
  serialized_end=1873,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
OK = 0
CANCELLED = 1
UNKNOWN = 2
INVALID_ARGUMENT = 3
DEADLINE_EXCEEDED = 4
NOT_FOUND = 5
ALREADY_EXISTS = 6
PERMISSION_DENIED = 7
UNAUTHENTICATED = 16
RESOURCE_EXHAUSTED = 8
FAILED_PRECONDITION = 9
ABORTED = 10
OUT_OF_RANGE = 11
UNIMPLEMENTED = 12
INTERNAL = 13
UNAVAILABLE = 14
DATA_LOSS = 15
BAD_NAME = 100
NAME_TAKEN = 101
VERSION_MISMATCH = 102



_CREATEPROJECTREQUEST = _descriptor.Descriptor(
  name='CreateProjectRequest',
  full_name='CreateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='CreateProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=69,
)


_GETPROJECTREQUEST = _descriptor.Descriptor(
  name='GetProjectRequest',
  full_name='GetProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='GetProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=110,
)


_PROJECTINFO = _descriptor.Descriptor(
  name='ProjectInfo',
  full_name='ProjectInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ProjectInfo.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=145,
)


_PROJECTINFORESPONSE = _descriptor.Descriptor(
  name='ProjectInfoResponse',
  full_name='ProjectInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ProjectInfoResponse.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='ProjectInfoResponse.error', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=214,
)


_GETDATASETREQUEST = _descriptor.Descriptor(
  name='GetDatasetRequest',
  full_name='GetDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='GetDatasetRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='GetDatasetRequest.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=275,
)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
  name='CreateDatasetRequest',
  full_name='CreateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='CreateDatasetRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='CreateDatasetRequest.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='CreateDatasetRequest.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=376,
)


_UPDATEDATASETREQUEST = _descriptor.Descriptor(
  name='UpdateDatasetRequest',
  full_name='UpdateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='UpdateDatasetRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='UpdateDatasetRequest.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='UpdateDatasetRequest.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=477,
)


_LISTPROJECTSREQUEST = _descriptor.Descriptor(
  name='ListProjectsRequest',
  full_name='ListProjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=500,
)


_LISTPROJECTSRESPONSE = _descriptor.Descriptor(
  name='ListProjectsResponse',
  full_name='ListProjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='ListProjectsResponse.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='ListProjectsResponse.error', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=582,
)


_LISTDATASETSREQUEST = _descriptor.Descriptor(
  name='ListDatasetsRequest',
  full_name='ListDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ListDatasetsRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=625,
)


_LISTDATASETSRESPONSE = _descriptor.Descriptor(
  name='ListDatasetsResponse',
  full_name='ListDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datasets', full_name='ListDatasetsResponse.datasets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='ListDatasetsResponse.error', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=707,
)


_DATASETINFO = _descriptor.Descriptor(
  name='DatasetInfo',
  full_name='DatasetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='DatasetInfo.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='DatasetInfo.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_timestamp', full_name='DatasetInfo.update_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample', full_name='DatasetInfo.sample', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='DatasetInfo.description', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='DatasetInfo.summary', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=852,
)


_DATASETINFORESPONSE = _descriptor.Descriptor(
  name='DatasetInfoResponse',
  full_name='DatasetInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='DatasetInfoResponse.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='DatasetInfoResponse.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_timestamp', full_name='DatasetInfoResponse.update_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample', full_name='DatasetInfoResponse.sample', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='DatasetInfoResponse.description', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='DatasetInfoResponse.summary', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='DatasetInfoResponse.error', index=6,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=1031,
)


_ADDDATASETACTIVITYREQUEST = _descriptor.Descriptor(
  name='AddDatasetActivityRequest',
  full_name='AddDatasetActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='AddDatasetActivityRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='AddDatasetActivityRequest.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multiline_text', full_name='AddDatasetActivityRequest.multiline_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='AddDatasetActivityRequest.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='AddDatasetActivityRequest.level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1176,
)


_ADDDATASETACTIVITYRESPONSE = _descriptor.Descriptor(
  name='AddDatasetActivityResponse',
  full_name='AddDatasetActivityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='AddDatasetActivityResponse.error', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1232,
)


_STATREQUEST = _descriptor.Descriptor(
  name='StatRequest',
  full_name='StatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1247,
)


_STATRESPONSE = _descriptor.Descriptor(
  name='StatResponse',
  full_name='StatResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='StatResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_count', full_name='StatResponse.event_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='StatResponse.error', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1327,
)


_RESETREQUEST = _descriptor.Descriptor(
  name='ResetRequest',
  full_name='ResetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1329,
  serialized_end=1343,
)


_APIERROR = _descriptor.Descriptor(
  name='ApiError',
  full_name='ApiError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='ApiError.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='ApiError.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail_code', full_name='ApiError.detail_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail_args', full_name='ApiError.detail_args', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='ApiError.details', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1345,
  serialized_end=1458,
)


_EMPTYRESPONSE = _descriptor.Descriptor(
  name='EmptyResponse',
  full_name='EmptyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='EmptyResponse.error', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1460,
  serialized_end=1501,
)

_PROJECTINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_CREATEDATASETREQUEST.fields_by_name['meta'].message_type = vo__pb2._DATASETMETADATADELTA
_UPDATEDATASETREQUEST.fields_by_name['meta'].message_type = vo__pb2._DATASETMETADATADELTA
_LISTPROJECTSRESPONSE.fields_by_name['projects'].message_type = _PROJECTINFO
_LISTPROJECTSRESPONSE.fields_by_name['error'].message_type = _APIERROR
_LISTDATASETSRESPONSE.fields_by_name['datasets'].message_type = _DATASETINFO
_LISTDATASETSRESPONSE.fields_by_name['error'].message_type = _APIERROR
_DATASETINFO.fields_by_name['sample'].message_type = vo__pb2._SAMPLE
_DATASETINFORESPONSE.fields_by_name['sample'].message_type = vo__pb2._SAMPLE
_DATASETINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_ADDDATASETACTIVITYREQUEST.fields_by_name['level'].enum_type = vo__pb2._ACTIVITY_LEVEL
_ADDDATASETACTIVITYRESPONSE.fields_by_name['error'].message_type = _APIERROR
_STATRESPONSE.fields_by_name['error'].message_type = _APIERROR
_APIERROR.fields_by_name['code'].enum_type = _STATUSCODE
_EMPTYRESPONSE.fields_by_name['error'].message_type = _APIERROR
DESCRIPTOR.message_types_by_name['CreateProjectRequest'] = _CREATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['GetProjectRequest'] = _GETPROJECTREQUEST
DESCRIPTOR.message_types_by_name['ProjectInfo'] = _PROJECTINFO
DESCRIPTOR.message_types_by_name['ProjectInfoResponse'] = _PROJECTINFORESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetRequest'] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasetRequest'] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatasetRequest'] = _UPDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsRequest'] = _LISTPROJECTSREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsResponse'] = _LISTPROJECTSRESPONSE
DESCRIPTOR.message_types_by_name['ListDatasetsRequest'] = _LISTDATASETSREQUEST
DESCRIPTOR.message_types_by_name['ListDatasetsResponse'] = _LISTDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['DatasetInfo'] = _DATASETINFO
DESCRIPTOR.message_types_by_name['DatasetInfoResponse'] = _DATASETINFORESPONSE
DESCRIPTOR.message_types_by_name['AddDatasetActivityRequest'] = _ADDDATASETACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['AddDatasetActivityResponse'] = _ADDDATASETACTIVITYRESPONSE
DESCRIPTOR.message_types_by_name['StatRequest'] = _STATREQUEST
DESCRIPTOR.message_types_by_name['StatResponse'] = _STATRESPONSE
DESCRIPTOR.message_types_by_name['ResetRequest'] = _RESETREQUEST
DESCRIPTOR.message_types_by_name['ApiError'] = _APIERROR
DESCRIPTOR.message_types_by_name['EmptyResponse'] = _EMPTYRESPONSE
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

ProjectInfo = _reflection.GeneratedProtocolMessageType('ProjectInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTINFO,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ProjectInfo)
  })
_sym_db.RegisterMessage(ProjectInfo)

ProjectInfoResponse = _reflection.GeneratedProtocolMessageType('ProjectInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ProjectInfoResponse)
  })
_sym_db.RegisterMessage(ProjectInfoResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ListDatasetsRequest)
  })
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ListDatasetsResponse)
  })
_sym_db.RegisterMessage(ListDatasetsResponse)

DatasetInfo = _reflection.GeneratedProtocolMessageType('DatasetInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASETINFO,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:DatasetInfo)
  })
_sym_db.RegisterMessage(DatasetInfo)

DatasetInfoResponse = _reflection.GeneratedProtocolMessageType('DatasetInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:DatasetInfoResponse)
  })
_sym_db.RegisterMessage(DatasetInfoResponse)

AddDatasetActivityRequest = _reflection.GeneratedProtocolMessageType('AddDatasetActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDDATASETACTIVITYREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:AddDatasetActivityRequest)
  })
_sym_db.RegisterMessage(AddDatasetActivityRequest)

AddDatasetActivityResponse = _reflection.GeneratedProtocolMessageType('AddDatasetActivityResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDDATASETACTIVITYRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:AddDatasetActivityResponse)
  })
_sym_db.RegisterMessage(AddDatasetActivityResponse)

StatRequest = _reflection.GeneratedProtocolMessageType('StatRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:StatRequest)
  })
_sym_db.RegisterMessage(StatRequest)

StatResponse = _reflection.GeneratedProtocolMessageType('StatResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:StatResponse)
  })
_sym_db.RegisterMessage(StatResponse)

ResetRequest = _reflection.GeneratedProtocolMessageType('ResetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ResetRequest)
  })
_sym_db.RegisterMessage(ResetRequest)

ApiError = _reflection.GeneratedProtocolMessageType('ApiError', (_message.Message,), {
  'DESCRIPTOR' : _APIERROR,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ApiError)
  })
_sym_db.RegisterMessage(ApiError)

EmptyResponse = _reflection.GeneratedProtocolMessageType('EmptyResponse', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:EmptyResponse)
  })
_sym_db.RegisterMessage(EmptyResponse)



_CATALOG = _descriptor.ServiceDescriptor(
  name='Catalog',
  full_name='Catalog',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1876,
  serialized_end=2475,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateProject',
    full_name='Catalog.CreateProject',
    index=0,
    containing_service=None,
    input_type=_CREATEPROJECTREQUEST,
    output_type=_PROJECTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProject',
    full_name='Catalog.GetProject',
    index=1,
    containing_service=None,
    input_type=_GETPROJECTREQUEST,
    output_type=_PROJECTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListProjects',
    full_name='Catalog.ListProjects',
    index=2,
    containing_service=None,
    input_type=_LISTPROJECTSREQUEST,
    output_type=_LISTPROJECTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataset',
    full_name='Catalog.CreateDataset',
    index=3,
    containing_service=None,
    input_type=_CREATEDATASETREQUEST,
    output_type=_DATASETINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataset',
    full_name='Catalog.GetDataset',
    index=4,
    containing_service=None,
    input_type=_GETDATASETREQUEST,
    output_type=_DATASETINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatasets',
    full_name='Catalog.ListDatasets',
    index=5,
    containing_service=None,
    input_type=_LISTDATASETSREQUEST,
    output_type=_LISTDATASETSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataset',
    full_name='Catalog.UpdateDataset',
    index=6,
    containing_service=None,
    input_type=_UPDATEDATASETREQUEST,
    output_type=_EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddDatasetActivity',
    full_name='Catalog.AddDatasetActivity',
    index=7,
    containing_service=None,
    input_type=_ADDDATASETACTIVITYREQUEST,
    output_type=_ADDDATASETACTIVITYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Stat',
    full_name='Catalog.Stat',
    index=8,
    containing_service=None,
    input_type=_STATREQUEST,
    output_type=_STATRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Reset',
    full_name='Catalog.Reset',
    index=9,
    containing_service=None,
    input_type=_RESETREQUEST,
    output_type=_EMPTYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CATALOG)

DESCRIPTOR.services_by_name['Catalog'] = _CATALOG

# @@protoc_insertion_point(module_scope)



from typing import Optional, List

from .cl_bases import *
from . import vo_pb2 as vo

from .cl_dataset import Dataset


class Project:


    def __init__(self, ctx: Context, project_id: str):
        self.project_id = project_id
        self.ctx = ctx




    def get_dataset(self, id:str) -> Dataset:

        get = api.GetDatasetRequest(project_id=self.project_id, dataset_id=id)
        resp = self.ctx.get_dataset(get)



        return Dataset(self.ctx, project_id=self.project_id, dataset_id=resp.dataset_id)

    def list_datasets(self) -> List[Dataset]:
        get = api.ListDatasetsRequest(project_id=self.project_id)
        resp = self.ctx.list_datasets(get)

        res = []

        d: api.DatasetInfoResponse
        for d in resp.datasets:
            res.append(Dataset(self.ctx, project_id=d.project_id, dataset_id=d.dataset_id))

        return res

    def add_dataset(self, dataset_id:str,
                    description: Optional[str] = None,
                    summary: Optional[str] = None) -> Dataset:
        meta = vo.DatasetMetadataDelta(

        )
        if description:
            meta.description_set = True
            meta.description = description

        if summary:
            meta.summary_set = True
            meta.summary = summary

        new = api.CreateDatasetRequest(
            project_id=self.project_id,
            dataset_id=dataset_id,
            meta=meta
        )

        resp = self.ctx.create_dataset(new)
        return Dataset(
            self.ctx,
            project_id=self.project_id,
            dataset_id=resp.dataset_id,

        )

    def get_or_create_dataset(self, dataset_id: str) -> Dataset:
        try:
            return self.get_dataset(dataset_id)
        except errors.NotFound:
            pass

        return self.add_dataset(dataset_id)





import importlib


def get_package_version(pkg):


    try:
        return pkg.__version__
    except AttributeError:
        pass
    try:
        return str(pkg.version)
    except AttributeError:
        pass
    try:
        return ".".join(map(str, pkg.version_info))
    except AttributeError:
        return None


def get_package_info(pkgs):
    """ get package versions for the passed required & optional packages """

    pversions = []
    for modname in pkgs:


        try:
            mod = importlib.import_module(modname)
            ver = get_package_version(mod)
            pversions.append((modname, ver))
        except Exception:
            pass

    return pversions


import setuptools

import os

with open("README.md", "r") as fh:
    long_description = fh.read()

version = os.getenv("VERSION")

if not version:
    version = "dev"


setuptools.setup(
    name="ml_pipelines",
    version=version,
    author="Rinat Abdullin",
    author_email="rinat@abdullin.com",
    description="Python client for ML Pipelines",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bitgn/ml-pipelines",
    packages=setuptools.find_packages(),
    install_requires=[
        'grpcio>=1.12.0',
        'protobuf'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Education"
    ],
)